%define plugin	live

%define url_ver %(tr . - <<< %{version})

Summary:	VDR plugin: Live Integrated VDR Environment
Name:		vdr-plugin-%plugin
Version:	3.1.11
Release:	%mkrel 1
Group:		Video/Utilities
License:	GPLv2+
URL:		https://github.com/MarkusEh/vdr-plugin-live/
Source0:	https://github.com/MarkusEh/vdr-plugin-live/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	vdr-devel >= 1.6.0
BuildRequires:	tntnet-devel
BuildRequires:	boost-devel
BuildRequires:	openssl-devel
BuildRequires:	epgsearch-devel >= 0.9.24
BuildRequires:	pcrecpp-devel
Requires:	vdr-abi = %vdr_abi

%description
Live, the "Live Interactive VDR Environment", is a plugin providing
the possibility to interactively control the VDR and some of its
plugins by a web interface.

Unlike external utility programs that communicate with VDR and its
plugins by SVDRP, Live has direct access to VDR's data structures
and is thus very fast.

%prep
%autosetup -p1

# epgsearch-devel
rm -rf epgsearch
sed -i 's,"epgsearch/services.h",<vdr/epgsearch/services.h>,' epgsearch.cpp timerconflict.cpp
%vdr_plugin_prep

%vdr_plugin_params_begin %plugin
# use PORT to listen for incoming connections instead of 8008
var=PORT
param="-p PORT"
# bind server only to specified IP
# multiple IPs can be separated with a space
var=BIND_IP
param=--ip=MULTIPLE_PARAMS
# use SSLPORT to listen for incoming ssl connections instead of 8443
var=SSLPORT
param="-s PORT"
# full path to a custom ssl certificate file
var=CERT
param="-c CERT"
default="%{_sysconfdir}/pki/tls/private/vdr-%plugin.pem"
# log level for tntnet (values: INFO, DEBUG,...)
var=LOGLEVEL
param="-l LOGLEVEL"
# directory for epgimages
var=EPGIMAGES
param="-e EPGIMAGES"
default="%{_vdr_epgimagesdir}"
%vdr_plugin_params_end

%build

%vdr_plugin_build

%install
%vdr_plugin_install

install -d -m755 %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}
touch %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}/httpd.config
touch %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}/httpd.properties

install -d -m755 %{buildroot}%{_vdr_plugin_datadir}
cp -a live %{buildroot}%{_vdr_plugin_datadir}/
for dir in %plugin/*; do
	ln -s %{_vdr_plugin_datadir}/$dir %{buildroot}%{_vdr_plugin_cfgdir}/$dir
done

%post
%_create_ssl_certificate -g vdr -b vdr-%plugin

%files -f %plugin.vdr
%doc CONTRIBUTORS HISTORY README
%dir %attr(-,vdr,vdr) %{_vdr_plugin_cfgdir}/%{plugin}
%ghost %{_vdr_plugin_cfgdir}/%{plugin}/httpd.config
%ghost %{_vdr_plugin_cfgdir}/%{plugin}/httpd.properties
%{_vdr_plugin_cfgdir}/%{plugin}/css
%{_vdr_plugin_cfgdir}/%{plugin}/img
%{_vdr_plugin_cfgdir}/%{plugin}/js
%{_vdr_plugin_cfgdir}/%{plugin}/themes
%{_vdr_plugin_datadir}/%{plugin}


%changelog
* Thu Mar 30 2023 philippedidier <philippedidier> 3.1.11-1.mga9
+ Revision: 1950802
- new version 3.1.11 - built with new epgrseaqrch 2.4.2-2 - allow parallel build

* Sun Oct 02 2022 wally <wally> 3.1.7-1.mga9
+ Revision: 1894105
- new version 3.1.7

* Tue Aug 16 2022 neoclust <neoclust> 2.3.1-3.mga9
+ Revision: 1878119
- Build against new vdr

* Wed Mar 30 2022 umeabot <umeabot> 2.3.1-2.mga9
+ Revision: 1835613
- Mageia 9 Mass Rebuild

* Sun Aug 22 2021 wally <wally> 2.3.1-1.mga9
+ Revision: 1742278
- new version 2.3.1
- rebuild for vdr 2.4.6

* Fri Feb 14 2020 umeabot <umeabot> 0.3.0-12.mga8
+ Revision: 1517765
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.3.0-11.mga7
+ Revision: 1301585
- Mageia 7 Mass Rebuild

* Sat Aug 04 2018 wally <wally> 0.3.0-10.mga7
+ Revision: 1247174
- backport upstream fixes to fix FTBFS with gcc >= 6

* Tue Feb 09 2016 umeabot <umeabot> 0.3.0-9.mga6
+ Revision: 951648
- Mageia 6 Mass Rebuild

* Mon Jan 05 2015 anssi <anssi> 0.3.0-8.mga5
+ Revision: 808491
- rebuild with new vdr-devel with cauldron-compatible macros

* Mon Jan 05 2015 anssi <anssi> 0.3.0-7.mga5
+ Revision: 808456
- rebuild for new VDR

* Mon Nov 24 2014 anssi <anssi> 0.3.0-6.mga5
+ Revision: 798672
- rebuild for new VDR
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Feb 09 2014 anssi <anssi> 0.3.0-3.mga5
+ Revision: 587670
- rebuild for new tntnet

* Tue Oct 22 2013 umeabot <umeabot> 0.3.0-2.mga4
+ Revision: 544763
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 anssi <anssi> 0.3.0-1.mga4
+ Revision: 498174
- new version 0.3.0
- drop upstreamed patches
- fix build with tntnet 2.2 (patch from upstream)

* Mon Jan 14 2013 umeabot <umeabot> 0.2.0-10.mga3
+ Revision: 385277
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 pterjan <pterjan> 0.2.0-9.mga3
+ Revision: 335478
- Better fix for new rpm

* Wed Dec 26 2012 pterjan <pterjan> 0.2.0-8.mga3
+ Revision: 335419
- Workaround new rpm limitation

* Thu Dec 06 2012 pterjan <pterjan> 0.2.0-7.mga3
+ Revision: 327094
- Add an upstream patch fixing build
+ malo <malo>
- spec clean-up
- update RPM group

* Wed Mar 07 2012 anssi <anssi> 0.2.0-6.mga2
+ Revision: 221046
- rebuild for VDR 1.7.25

* Sat Feb 25 2012 anssi <anssi> 0.2.0-5.mga2
+ Revision: 214814
- rebuild for VDR 1.7.23
- handle timer titles with colon properly (timers_colon.dpatch,
  from e-tobi)

* Sat May 14 2011 anssi <anssi> 0.2.0-4.mga1
+ Revision: 98414
- remove old scriptlets
- imported package vdr-plugin-live

